@@ -67,7 +67,7 @@ static struct option program_options[] = {
 /* Function to print the version - near the top for easy modification. */
 void PrintVersion(char* ProgramName)
 {
-	printf("%s, v 1.5.6, 22 July 2007. Daniel Foote, 2005-2007. GNU GPL.\n", ProgramName);
+	printf("%s, v 1.6.0, 5 April 2009. Daniel Foote, 2005-2009. GNU GPL.\n", ProgramName);
 }
 
 /* Function to print the usage info. */
@@ -82,7 +82,7 @@ void PrintUsage(char* ProgramName)
 	printf("   Interpolation is linear, points rounded if disabled.\n");
 	printf("--verbose or -v: show what has been selected.\n");
 	printf("--datum or -d datum: specify measurement datum. If not set, WGS-84 used.\n");
-	printf("--no-write or -n: do not write the exif data. Useful with --show.\n");
+	printf("--no-write or -n: do not write the exif data. Useful with --verbose.\n");
 	printf("--max-dist or -m time: max time outside points that photo will be matched.\n");
 	printf("   Time is in seconds.\n");
 	printf("--show or -s: Just show the GPS data from the given files, if it exists.\n");
